##  Collect Data from Fact Sheet Owners
You can collect data from fact sheet owners using one of the following methods:
  * [Onboarding dashboard for fact sheet owners](https://help.sap.com/docs/leanix/ea/collect-data-from-fact-sheet-owners?locale=en-US&state=PRODUCTION&version=CLOUD#loiof506c30217a44594bfb46eb9a3e49729__section_smp_t5n_ghc): Onboard fact sheet owners and collect data simultaneously.
    * Fact sheet owners sign in to the workspace and learn how to use SAP LeanIX. This helps them understand their key tasks and learn how to collaborate with others.
    * After onboarding, fact sheet owners can continue using the dashboard to get an overview of their fact sheets and the tasks they need to complete.
  * [Surveys](https://help.sap.com/docs/leanix/ea/collect-data-from-fact-sheet-owners?locale=en-US&state=PRODUCTION&version=CLOUD#loiof506c30217a44594bfb46eb9a3e49729__section_ajt_t5n_ghc): Collect data by sending surveys to fact sheet owners.
    * Fact sheet owners don't need to sign in to your workspace to contribute to fact sheet data.
    * You'll need to onboard fact sheet owners into SAP LeanIX later to guide them through the key features and their tasks.
